pub struct ReplicatedEmbeddedStore { /* private fields */ }Implementations
Sourceimpl ReplicatedEmbeddedStore
impl ReplicatedEmbeddedStore
pub fn new(shard_count: usize, config: ReplicationConfig) -> Result<Self>
pub fn with_route_mode( shard_count: usize, route_mode: EmbeddedRouteMode, config: ReplicationConfig, ) -> Result<Self>
pub fn get(&self, key: &[u8]) -> Option<Bytes>
pub fn set(&self, key: Bytes, value: Bytes, ttl_ms: Option<u64>)
pub fn delete(&self, key: &[u8]) -> bool
pub fn expire(&self, key: &[u8], expire_at_ms: u64) -> bool
Sourcepub fn snapshot(&self) -> ReplicationSnapshot
pub fn snapshot(&self) -> ReplicationSnapshot
Captures a consistent snapshot for replica bootstrap.
Watermarks are taken first so any mutation that lands between the
watermark read and the entry read is reflected in the entries. Catch-up
from this watermark may re-deliver those mutations, but apply_mutation
deduplicates by sequence so re-delivery is a no-op.
pub fn catch_up_replica(&self, replica: &mut ReplicationReplica) -> Result<()>
pub fn primary(&self) -> Arc<ReplicationPrimary> ⓘ
pub fn metrics_snapshot(&self) -> ReplicationMetricsSnapshot
pub fn inner(&self) -> &EmbeddedStore