OwnedEmbeddedWorkerShards

Struct OwnedEmbeddedWorkerShards 

pub struct OwnedEmbeddedWorkerShards { /* private fields */ }
One worker-local shard set for the slot-owned embedded path.

The worker owns every shard in this set exclusively, so routed operations execute without any mutex on the hot path.

Implementations

Source

impl OwnedEmbeddedWorkerShards

pub fn shard_count(&self) -> usize

pub fn route_mode(&self) -> EmbeddedRouteMode

pub fn worker_shard_count(&self) -> usize

pub fn owns_shard(&self, shard_id: usize) -> bool

pub fn route_key(&self, key: &[u8]) -> EmbeddedKeyRoute

pub fn prepare_point_key(&self, key: &[u8]) -> PreparedPointKey

pub fn route_session(&self, session_prefix: &[u8]) -> EmbeddedSessionRoute

pub fn begin_read_session(&mut self) -> OwnedEmbeddedWorkerReadSession<'_>

pub fn get_ref_no_ttl_routed( &mut self, route: EmbeddedKeyRoute, key: &[u8], ) -> Option<&[u8]>

pub fn get_prepared_ref_no_ttl( &mut self, prepared: &PreparedPointKey, ) -> Option<&[u8]>

pub fn get_view_routed_no_ttl( &mut self, route: EmbeddedKeyRoute, key: &[u8], ) -> OwnedEmbeddedReadView

pub fn set_slice_routed_no_ttl( &mut self, route: EmbeddedKeyRoute, key: &[u8], value: &[u8], )

pub fn batch_set_session_slices_no_ttl<I, K, V>( &mut self, session_prefix: &[u8], items: I, )
where I: IntoIterator<Item = (K, V)>, K: AsRef<[u8]>, V: AsRef<[u8]>,

pub fn batch_set_session_packed_no_ttl(&mut self, packed: PackedSessionWrite)

pub fn batch_get_session_view_no_ttl( &mut self, session_prefix: &[u8], keys: &[Bytes], ) -> OwnedEmbeddedSessionBatchView

pub fn batch_get_session_view_prehashed_no_ttl( &mut self, session_prefix: &[u8], keys: &[Bytes], key_hashes: &[u64], ) -> OwnedEmbeddedSessionBatchView

pub fn batch_get_session_view_routed_no_ttl( &mut self, route: EmbeddedSessionRoute, keys: &[Bytes], ) -> OwnedEmbeddedSessionBatchView

pub fn batch_get_session_view_prehashed_routed_no_ttl( &mut self, route: EmbeddedSessionRoute, keys: &[Bytes], key_hashes: &[u64], ) -> OwnedEmbeddedSessionBatchView

pub fn batch_get_session_packed_no_ttl( &mut self, session_prefix: &[u8], keys: &[Bytes], ) -> PackedBatch

pub fn batch_get_session_packed_routed_no_ttl( &mut self, route: EmbeddedSessionRoute, keys: &[Bytes], ) -> PackedBatch

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn process_maintenance(&mut self) -> usize

pub fn restore_entries<I>(&mut self, entries: I)
where I: IntoIterator<Item = StoredEntry>,

pub fn get(&mut self, key: &[u8]) -> Option<Bytes>

pub fn get_view(&mut self, key: &[u8]) -> OwnedEmbeddedReadView

pub fn batch_get(&mut self, keys: Vec<Bytes>) -> Vec<Option<Bytes>>

pub fn batch_get_view(&mut self, keys: &[Bytes]) -> OwnedEmbeddedBatchReadView

pub fn batch_get_session_view( &mut self, session_prefix: &[u8], keys: &[Bytes], ) -> OwnedEmbeddedSessionBatchView

pub fn batch_get_session_view_prehashed( &mut self, session_prefix: &[u8], keys: &[Bytes], key_hashes: &[u64], ) -> OwnedEmbeddedSessionBatchView

pub fn batch_get_session_packed_view_prehashed( &mut self, session_prefix: &[u8], keys: &[Bytes], key_hashes: &[u64], ) -> Option<OwnedEmbeddedSessionPackedView>

pub fn batch_get_session_packed_view( &mut self, session_prefix: &[u8], keys: &[Bytes], ) -> Option<OwnedEmbeddedSessionPackedView>

pub fn batch_get_session_packed( &mut self, session_prefix: &[u8], keys: &[Bytes], ) -> PackedBatch

pub fn batch_get_packed(&mut self, keys: &[Bytes]) -> PackedBatch

pub fn set(&mut self, key: Bytes, value: Bytes, ttl_ms: Option<u64>)

pub fn batch_set(&mut self, items: Vec<(Bytes, Bytes)>, ttl_ms: Option<u64>)

pub fn batch_set_session_owned_no_ttl( &mut self, session_prefix: Bytes, items: Vec<(Bytes, Bytes)>, )

pub fn delete(&mut self, key: &[u8]) -> bool

pub fn exists(&mut self, key: &[u8]) -> bool