pub struct SharedEmbeddedRefMut<'a> { /* private fields */ }Expand description
Mutable point-key guard returned by SharedEmbeddedStore::get_mut.
Implementations
Sourceimpl RefMut<'_>
impl RefMut<'_>
Sourcepub fn value(&self) -> Option<&[u8]>
pub fn value(&self) -> Option<&[u8]>
Returns the current value bytes when the key is still present.
Sourcepub fn set(&mut self, value: SharedBytes)
pub fn set(&mut self, value: SharedBytes)
Replaces the value without changing the key.
Sourcepub fn remove(self) -> Option<SharedBytes>
pub fn remove(self) -> Option<SharedBytes>
Removes the entry and returns the stored bytes when present.