Module config

Module config 

Runtime configuration for the embedded store and optional server.

FastCacheConfig can be loaded from TOML with FastCacheConfig::load_from_path or serialized with FastCacheConfig::store_to_path. The defaults are suitable for local development and derive the shard count and tier sizes from the host when possible.

Structs

CacheGeometry
Host CPU cache geometry used to derive tier defaults.
FastCacheConfig
Top-level configuration for fast-cache-server.
PersistenceConfig
WAL and snapshot persistence settings.
ReplicationConfig
Native replication configuration.
TierConfig
Capacity settings for the hot, warm, and cold in-memory tiers.
WalTcpExportConfig
Optional live WAL export settings.

Enums

EvictionPolicy
Memory-limit eviction policy.
ReplicationCompression
Native replication compression.
ReplicationRole
Native replication role.
ReplicationSendPolicy
Native replication send policy.
WalTcpExportMode
TCP WAL export topology.