pub enum FastCommand<'a> {
Show 50 variants
Ping(Option<&'a [u8]>),
Auth,
Hello {
proto: Option<u64>,
},
Select {
db: u64,
},
Quit,
Echo {
payload: &'a [u8],
},
Info,
Command,
CommandDocs,
ConfigGet {
patterns: Vec<&'a [u8]>,
},
DbSize,
Time,
ClientGetName,
ClientSetName {
name: &'a [u8],
},
ClientId,
ClientList,
ClientKill,
Get {
key: &'a [u8],
},
Set {
key: &'a [u8],
value: &'a [u8],
},
SetEx {
key: &'a [u8],
value: &'a [u8],
ttl_ms: u64,
},
GetEx {
key: &'a [u8],
ttl_ms: u64,
},
Delete {
key: &'a [u8],
},
Exists {
key: &'a [u8],
},
Ttl {
key: &'a [u8],
},
Expire {
key: &'a [u8],
ttl_ms: u64,
},
MGet {
keys: Vec<&'a [u8]>,
},
MSet {
items: Vec<(&'a [u8], &'a [u8])>,
},
HSet {
key: &'a [u8],
field: &'a [u8],
value: &'a [u8],
},
HGet {
key: &'a [u8],
field: &'a [u8],
},
HDel {
key: &'a [u8],
field: &'a [u8],
},
HLen {
key: &'a [u8],
},
HMGet {
key: &'a [u8],
fields: Vec<&'a [u8]>,
},
LPush {
key: &'a [u8],
values: Vec<&'a [u8]>,
},
RPush {
key: &'a [u8],
values: Vec<&'a [u8]>,
},
LPop {
key: &'a [u8],
},
RPop {
key: &'a [u8],
},
LLen {
key: &'a [u8],
},
LIndex {
key: &'a [u8],
index: i64,
},
LRange {
key: &'a [u8],
start: i64,
stop: i64,
},
SAdd {
key: &'a [u8],
members: Vec<&'a [u8]>,
},
SRem {
key: &'a [u8],
members: Vec<&'a [u8]>,
},
SIsMember {
key: &'a [u8],
member: &'a [u8],
},
SCard {
key: &'a [u8],
},
SMembers {
key: &'a [u8],
},
ZAdd {
key: &'a [u8],
score: f64,
member: &'a [u8],
},
ZRem {
key: &'a [u8],
member: &'a [u8],
},
ZScore {
key: &'a [u8],
member: &'a [u8],
},
ZCard {
key: &'a [u8],
},
ZRange {
key: &'a [u8],
start: i64,
stop: i64,
},
RespCommand {
parts: Vec<&'a [u8]>,
},
}Variants
Ping(Option<&'a [u8]>)
Auth
Hello
Select
Quit
Echo
Info
Command
CommandDocs
ConfigGet
DbSize
Time
ClientGetName
ClientSetName
ClientId
ClientList
ClientKill
Get
Set
SetEx
GetEx
Delete
Exists
Ttl
Expire
MGet
MSet
HSet
HGet
HDel
HLen
HMGet
LPush
RPush
LPop
RPop
LLen
LIndex
LRange
SAdd
SRem
SIsMember
SCard
SMembers
ZAdd
ZRem
ZScore
ZCard
ZRange
RespCommand
Generic FCNP wrapper for the Redis command surface.
The request body is a length-prefixed list of command parts, starting with the command name. The server returns the RESP reply bytes as an FCNP value so clients can use one native ingress path for the complete compatibility surface while hot commands keep their typed opcodes.
Implementations
Sourceimpl<'a> FastCommand<'a>
impl<'a> FastCommand<'a>