pub struct EmbeddedShardHandle<'a> { /* private fields */ }Expand description
Exclusive shard-local handle for slot-owned embedded workers.
This is the no-contention path for workloads that can guarantee one thread owns a shard’s slot range. The caller locks the shard once, then performs many point operations without re-entering the shared store routing path.
Implementations
Sourceimpl<'a> EmbeddedShardHandle<'a>
impl<'a> EmbeddedShardHandle<'a>
pub fn shard_id(&self) -> usize
pub fn get_ref_no_ttl_hashed( &mut self, key_hash: u64, key: &[u8], ) -> Option<&[u8]>
pub fn set_hashed_no_ttl<K, V>(&mut self, key_hash: u64, key: K, value: V)
pub fn set_slice_hashed_no_ttl( &mut self, key_hash: u64, key: &[u8], value: &[u8], )