pub type EmbeddedSessionBatchView = EmbeddedBatchReadView;Expand description
Session-scoped owned batch view.
This is currently just a clearer alias for the generic batch guard used by the Python API and the LLM benchmark path.
Aliased Type
pub struct EmbeddedSessionBatchView { /* private fields */ }